@@ -20,7 +20,7 @@ __author__ = "Ali Akhtari"
 __copyright__ = "Copyright 2020 Ali Akhtari <https://github.com/AliAkhtari78>"
 __credits__ = ["Ali Akhtari"]
 __license__ = "MIT"
-__version__ = "1.0.3"
+__version__ = "1.0.5"
 __maintainer__ = "Ali Akhtari"
 __email__ = "aliakhtari78@hotmail.com"
 __status__ = "Production"
@@ -31,6 +31,7 @@ import yaml
 import eyed3
 import os
 import logging
+from .request import Request
 
 logger = logging.getLogger(__name__)
 logger.setLevel(logging.DEBUG)
@@ -148,7 +149,9 @@ class Scraper:
                     'type_': type_,
                     'ERROR': None,
                 }
-            except:
+            except Exception as error:
+                if self.log:
+                    logger.error(error)
                 try:
                     bs_instance = BeautifulSoup(page_content, "lxml")
                     error = bs_instance.find('div', {'class': 'content'}).text
@@ -172,7 +175,9 @@ class Scraper:
                     try:
                         return self._image_downloader(url=cover_url, file_name=album_title,
                                                       path=path)
-                    except:
+                    except Exception as error:
+                        if self.log:
+                            logger.error(error)
                         return "Couldn't download the cover."
 
                 except:
@@ -221,8 +226,6 @@ class Scraper:
                 try:
                     return self._preview_mp3_downloader(url=preview_mp3, file_name=title + '-' + album_title, path=path,
                                                         with_cover=with_cover, cover_url=album_cover_url)
-
-
                 except Exception as error:
                     if self.log:
                         logger.error(error)
